<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Russian
</name>

<description>
   <am>Russian Language Meta-Package</am>
   <ar>Russian Language Meta-Package</ar>
   <bg>Russian Language Meta-Package</bg>
   <ca>Meta-paquet de llengua per a Rus</ca>
   <cs>Russian Language Meta-Package</cs>
   <da>Russisk sprog-metapakke</da>
   <de>Russisches Sprach-Meta-Paket</de>
   <el>Ρωσική γλώσσα</el>
   <en>Russian Language Meta-Package</en>
   <es>Russian Language Meta-Package</es>
   <et>Russian Language Meta-Package</et>
   <eu>Russian Language Meta-Package</eu>
   <fa>Russian Language Meta-Package</fa>
   <fi>Russian Language Meta-Package</fi>
   <fr>Méta-paquet pour langue russe</fr>
   <he_IL>Russian Language Meta-Package</he_IL>
   <hi>Russian Language Meta-Package</hi>
   <hr>Russian Language Meta-Package</hr>
   <hu>Russian Language Meta-Package</hu>
   <id>Russian Language Meta-Package</id>
   <is>Russian Language Meta-Package</is>
   <it>Meta-pacchetto della lingua russa</it>
   <ja_JP>Russian Language Meta-Package</ja_JP>
   <ja>Russian Language Meta-Package</ja>
   <kk>Russian Language Meta-Package</kk>
   <ko>Russian Language Meta-Package</ko>
   <lt>Russian Language Meta-Package</lt>
   <mk>Russian Language Meta-Package</mk>
   <nb>Russian Language Meta-Package</nb>
   <nl>Russische Taal Meta-Pakket</nl>
   <pl>Rosyjski metapakiet językowy</pl>
   <pt_BR>Russo Meta-Pacote de Idioma</pt_BR>
   <pt>Russo Meta-Pacote de Idioma</pt>
   <ro>Russian Language Meta-Package</ro>
   <ru>Мета-пакет русского языка</ru>
   <sk>Russian Language Meta-Package</sk>
   <sl>Russian Language Meta-Package</sl>
   <sq>Russian Language Meta-Package</sq>
   <sr>Russian Language Meta-Package</sr>
   <sv>Ryskt Språk-Meta-Paket </sv>
   <tr>Russian Language Meta-Package</tr>
   <uk>Russian Language Meta-Package</uk>
   <zh_CN>Russian Language Meta-Package</zh_CN>
   <zh_TW>Russian Language Meta-Package</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
aspell-ru
console-cyrillic
myspell-ru
irussian
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
aspell-ru
console-cyrillic
myspell-ru
irussian
</uninstall_package_names>
</app>
